@@ -164,7 +164,7 @@
 int	memfd;
 int	procsize;
 int	do_count;
-int	total_time;	/* total cpu time */
+long	total_time;	/* total cpu time */
 time_t	start_time;
 #define	    KMEM	"/dev/kmem"
 
@@ -201,6 +201,7 @@ struct nlist anlist;
 #define X_HZ            7
 #endif
 
+
 static struct nlist nlst[] = {
     { "_avenrun" },             /* 0 */
     { "_ccpu" },                /* 1 */
@@ -335,20 +336,19 @@ static char hostname [256];     /* Name of local host */
  *	       -3: If the queue was deleted while we were trying
  *		   to open the queue-ordering file.
  */
-int shoqbydesc (file, que_descr, flags, whomuid, requests, dae_present,
-		qmapfile, pipeqfile, qcomplexfile)
-struct confd *file;			/* NQS queue file containing.... */
-struct gendescr *que_descr;		/* the queue descriptor */
-long flags;				/* Display flags */
-uid_t whomuid;				/* Zero in on this user */
-struct reqset *requests;		/* Optional request selection set */
-short dae_present;			/* Boolean non-zero if the local NQS */
+int shoqbydesc (
+	struct confd *file,		/* NQS queue file containing.... */
+	struct gendescr *que_descr,	/* the queue descriptor */
+	long flags,			/* Display flags */
+	uid_t whomuid,			/* Zero in on this user */
+	struct reqset *requests,	/* Optional request selection set */
+	short dae_present,		/* Boolean non-zero if the local NQS */
 					/* daemon is present and running */
-struct confd *qmapfile;			/* NQS queue/device/destination */
+	struct confd *qmapfile,		/* NQS queue/device/destination */
 					/* mapping database file */
-struct confd *pipeqfile;		/* NQS pipe-queue destination */
+	struct confd *pipeqfile,	/* NQS pipe-queue destination */
 					/* database file */
-struct confd *qcomplexfile;             /* NQS queue complex definition file */
+	struct confd *qcomplexfile)     /* NQS queue complex definition file */
 {
 
 	char hostname [256];		/* Name of local host */
@@ -844,8 +844,7 @@ struct confd *qcomplexfile;             /* NQS queue complex definition file */
  *	char *get_units():
  *	Get quota units.
  */
-static char *get_units (units)
-register short units;
+static char *get_units (short units)
 {
 	switch (units) {
 	case QLM_BYTES:
@@ -879,11 +878,11 @@ register short units;
  *		1: if the request was selected for display;
  *		0: if not.
  */
-static int selrequest (qentry, flags, whomuid, requests)
-register struct qentry *qentry;		/* Request queue entry */
-long flags;				/* Display mode flags */
-uid_t whomuid;				/* Whom we are asking about */
-register struct reqset *requests;	/* Specific request select list */
+static int selrequest (
+	register struct qentry *qentry,	/* Request queue entry */
+	long flags,			/* Display mode flags */
+	uid_t whomuid,			/* Whom we are asking about */
+	register struct reqset *requests)/* Specific request select list */
 {
 	if (requests == (struct reqset *) 0 ) {	
 		if (flags & SHO_R_ALLUID) return (1);
@@ -948,11 +947,11 @@ register struct reqset *requests;	/* Specific request select list */
  *	void shocpulim():
  *	Display a CPU time limit quota.
  */
-static void shocpulim (cpu, explicit, infinite, que_descr)
-register struct cpulimit *cpu;
-long explicit;
-long infinite;
-struct gendescr *que_descr;
+static void shocpulim (
+	register struct cpulimit *cpu,
+	long explicit,
+	long infinite,
+	struct gendescr *que_descr)
 {
 	if (infinite == 0) {
 		printf ("= [%1lu.%1d, %1lu.%1d]",
@@ -980,11 +979,11 @@ struct gendescr *que_descr;
  *	void shogap():
  *	Display a gap in between requests we are interested in.
  */
-static void shogap (gaplow, gaphigh, state, flags)
-int gaplow;
-int gaphigh;
-char * state;
-int flags;
+static void shogap (
+	int gaplow,
+	int gaphigh,
+	char * state,
+	int flags)
 {
         if (flags & SHO_R_MONSANTO) return;
 	if (gaplow > gaphigh) return;
@@ -999,8 +998,7 @@ int flags;
  *	void shogrp():
  *	Display a group name.
  */
-static void shogrp (gid)
-unsigned long gid;
+static void shogrp (unsigned long gid)
 {
 	if (acccolumn >= 4) {
 		acccolumn = 0;
@@ -1017,8 +1015,7 @@ unsigned long gid;
  *	void shokey():
  *	Display column headings.
  */
-static void shokey (que_descr)
-register struct gendescr *que_descr;
+static void shokey (struct gendescr *que_descr)
 {
         if (que_descr->v.que.type == QUE_DEVICE) {
                 printf ("         REQUEST NAME        REQUEST ID            ");
@@ -1036,8 +1033,7 @@ register struct gendescr *que_descr;
  *	void shoomd():
  *	Display an output mode.
  */
-static void shoomd (mode)
-char mode;
+static void shoomd (char mode)
 {
 	if (mode & OMD_SPOOL) {
 		printf ("SPOOL\n");
@@ -1055,9 +1051,9 @@ char mode;
  *	void shoqueacc():
  *	Display the groups and users allowed to access a queue.
  */
-static void shoqueacc (file, que_descr)
-struct confd *file;
-struct gendescr *que_descr;
+static void shoqueacc (
+	struct confd *file,
+	struct gendescr *que_descr)
 {
 	void shousr();			/* Show user */
 	
@@ -1131,11 +1127,11 @@ struct gendescr *que_descr;
  *	void shoquedesmap():
  *	Display the destination set for a pipe queue.
  */
-static void shoquedesmap (que_descr, qmapfile, pipeqfile)
-struct gendescr *que_descr;		/* The queue descriptor */
-struct confd *qmapfile;			/* Queue/device/destination mapping */
+static void shoquedesmap (
+	struct gendescr *que_descr,	/* The queue descriptor */
+	struct confd *qmapfile,		/* Queue/device/destination mapping */
 					/* database file */
-struct confd *pipeqfile;		/* Pipe-destination database file */
+	struct confd *pipeqfile)	/* Pipe-destination database file */
 {
 	register struct gendescr *dbds1;/* NQS database file generic descr */
 	register struct gendescr *dbds2;/* NQS database file generic descr */
@@ -1273,18 +1269,17 @@ struct confd *pipeqfile;		/* Pipe-destination database file */
  *	void shoquehdr():
  *	Display the queue header.
  */
-static void shoquehdr (file, que_descr, dae_present, flags, hostname,
-		       qmapfile, pipeqfile, qcomplexfile)
-struct confd *file;			/* NQS queue file containing.... */
-struct gendescr *que_descr;		/* The Queue-descriptor */
-short dae_present;			/* Non-zero if the local NQS daemon */
+static void shoquehdr (
+	struct confd *file,		/* NQS queue file containing.... */
+	struct gendescr *que_descr,	/* The Queue-descriptor */
+	short dae_present,		/* Non-zero if the local NQS daemon */
 					/* is present and running */
-long flags;				/* Display mode flags */
-char *hostname;				/* Name of local host */
-struct confd *qmapfile;			/* Queue/device/destination mapping */
+	long flags,			/* Display mode flags */
+	char *hostname,			/* Name of local host */
+	struct confd *qmapfile,		/* Queue/device/destination mapping */
 					/* database file */
-struct confd *pipeqfile;		/* Pipe-destination database file */
-struct confd *qcomplexfile;             /* Queue complex definition file */
+	struct confd *pipeqfile,	/* Pipe-destination database file */
+	struct confd *qcomplexfile)     /* Queue complex definition file */
 {
         struct gendescr *qcom_descr;    /* A queue-complex-descriptor */
         register char *namep, *qname;
@@ -1421,8 +1416,7 @@ struct confd *qcomplexfile;             /* Queue complex definition file */
  *	void shoquelims():
  *	Display the limits associated with a queue.
  */
-static void shoquelims (que_descr)
-struct gendescr * que_descr;		/* The queue */
+static void shoquelims (struct gendescr *que_descr)
 {
 static char *unlimited = "UNLIMITED";
 static char *def = " <DEFAULT>";
@@ -1687,9 +1681,9 @@ static char *def = " <DEFAULT>";
  *	void shoquedevmap():
  *	Display the queue-to-device mappings for a queue.
  */
-static void shoquedevmap (que_descr, qmapfile)
-struct gendescr *que_descr;		/* The queue descriptor */
-struct confd *qmapfile;			/* Queue/device/destination mapping */
+static void shoquedevmap (
+	struct gendescr *que_descr,	/* The queue descriptor */
+	struct confd *qmapfile)		/* Queue/device/destination mapping */
 					/* database file */
 {
 	register struct gendescr *dbdsc;/* NQS database file generic descr */
@@ -1750,8 +1744,7 @@ struct confd *qmapfile;			/* Queue/device/destination mapping */
  *	void shoquetime():
  *	Display the cumulative cpu time used by requests in a queue.
  */
-static void shoquetime (que_descr)
-struct gendescr *que_descr;
+static void shoquetime (struct gendescr *que_descr)
 {
 	printf ("  Cumulative system space time = ");
 #if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
@@ -1788,11 +1781,11 @@ BSD SYSTEM TYPE
  *	void shoquolim():
  *	Display a quota limit.
  */
-static void shoquolim (quota, explicit, infinite, que_descr)
-register struct quotalimit *quota;
-long explicit;
-long infinite;
-struct gendescr *que_descr;
+static void shoquolim (
+	struct quotalimit *quota,
+	long explicit,
+	long infinite,
+	struct gendescr *que_descr)
 {
 	if (infinite == 0) {
 		printf ("= [%1lu %s, %1lu %s]", quota->max_quota,
@@ -1821,9 +1814,9 @@ struct gendescr *que_descr;
  *	void shoreqlims():
  *	Display the limits associated with a request.
  */
-static void shoreqlims (que_descr, rawreqp)
-struct gendescr *que_descr;		/* Needed to detect pipe queues */
-struct rawreq *rawreqp;			/* The request as a rawreq */
+static void shoreqlims (
+	struct gendescr *que_descr,	/* Needed to detect pipe queues */
+	struct rawreq *rawreqp)		/* The request as a rawreq */
 {
 	if (que_descr->v.que.type == QUE_PIPE ||
 	   (VALID_LIMITS & LIM_PRDRIVES)) {
@@ -1988,14 +1981,13 @@ struct rawreq *rawreqp;			/* The request as a rawreq */
  *	void shorequest():
  *	Display a request.
  */
-static void shorequest (qentry, reqstate, que_descr, nth_request, flags,
-			hostname)
-struct qentry *qentry;			/* Queue entry describing request */
-int reqstate;				/* Req state=[HOLDING,RUNNING,QUEUED] */
-struct gendescr *que_descr;		/* Queue file queue-descriptor */
-int nth_request;			/* N-th request number in the queue */
-long flags;				/* Display mode flags */
-char *hostname;				/* Local host name */
+static void shorequest (
+	struct qentry *qentry,		/* Queue entry describing request */
+	int reqstate,			/* Req state=[HOLDING,RUNNING,QUEUED] */
+	struct gendescr *que_descr,	/* Queue file queue-descriptor */
+	int nth_request,		/* N-th request number in the queue */
+	long flags,			/* Display mode flags */
+	char *hostname)			/* Local host name */
 {
 	char reqname [MAX_REQNAME+1];	/* Name of request */
 	char *status;			/* Request status */
@@ -2302,8 +2294,7 @@ char *hostname;				/* Local host name */
  *	void shousr():
  *	Display a user name.
  */
-static void shousr (uid)
-unsigned long uid;
+static void shousr (unsigned long uid)
 {
 	if (acccolumn >= 4) {
 		acccolumn = 0;
@@ -2320,9 +2311,7 @@ unsigned long uid;
  *      Show display title
  *
  */
-static void shotitle (string1, string2)
-char *string1;                          /* "Enhanced" title */
-char *string2;
+static void shotitle (char *string1, char *string2)
 {
         register int hdlen;
         register int chars;
@@ -2347,9 +2336,7 @@ char *string2;
  *      void shoqueline():
  *      Display queue summary separator line
  */
-static void shoqueline (queue_type, flags)
-short queue_type;
-long flags;
+static void shoqueline (short queue_type, long flags)
 {
         printf ("----------------------- ");
         switch (queue_type)     {
@@ -2375,11 +2362,99 @@ long flags;
 	printf("\n");
 }
 
+#if 	TAMU
+#include <sys/types.h>
+#include <sys/dir.h>
+	/* for IRIX 6, avoid 64 bit KMEM , and go straight to /proc */
+static summary(
+	pid_t	proc_family,		/* process family */
+	struct  rawreq	*rawreqp)
+{
+	struct	tm  *start_tm;
+	int	status;
+	int	days, hours, minutes;
+	int	max_time;
+        int     fd;
+        int     retval;
+	prpsinfo_t prpsinfo;
+        char char_pid[32];
+	pid_t	sesid;
+	DIR 	*dirp;
+	struct direct *dir;
+
+	total_time = start_time = 0;
+
+	/* use /proc to read leader info directly */
+        sprintf(char_pid, "/proc/pinfo/%05d", proc_family);
+        fd = open (char_pid, O_RDONLY);
+        if (fd != -1) {
+	    retval = ioctl(fd, PIOCPSINFO, &prpsinfo);
+	    start_time = prpsinfo.pr_start.tv_sec;
+	    sesid = prpsinfo.pr_sid;
+            close (fd);
+        }
+
+	/* walk /proc, accumulating time for all procs in sesid */
+	dirp = opendir("/proc/pinfo");
+	while ((dir = readdir(dirp)) != NULL) {
+		sprintf(char_pid, "/proc/pinfo/%s",dir->d_name);
+		fd = open(char_pid,O_RDONLY);
+		if (fd != -1) {
+			retval = ioctl(fd,PIOCPSINFO, &prpsinfo);
+			if (prpsinfo.pr_sid == sesid) {
+				total_time += prpsinfo.pr_time.tv_sec
+					   +  prpsinfo.pr_ctime.tv_sec;
+			}
+			close(fd);
+		}
+	}
+
+	if ( start_time ) {
+	    start_tm = localtime(&start_time);
+	    printf(" %2d/%2.2d %2.2d:%2.2d", start_tm->tm_mon+1,
+			start_tm->tm_mday,
+			start_tm->tm_hour,
+			start_tm->tm_min);
+	} else {
+	    printf("            ");
+	}
+	/*
+	 * Calculate and print the per process max time.
+	 */
+	max_time = rawreqp->v.bat.ppcputime.max_seconds;
+	days = max_time / (24 * 60 * 60);
+	max_time -= days * 24 * 60 * 60;
+	hours = max_time / (60 * 60);
+	max_time -= hours * 60 * 60;
+	minutes = max_time / 60;
+	max_time -= minutes * 60;
+	printf("  %3d %2d:%2.2d", days, hours, minutes);
+	/*
+	 * Calculate and print the total time used by all processes.
+	 */
+	if ( total_time ) {
+	    days = total_time / (24 * 60 * 60);
+	    total_time -= days * 24 * 60 * 60;
+	    hours = total_time / (60 * 60);
+	    total_time -= hours * 60 * 60;
+	    minutes = total_time / 60;
+	    total_time -= minutes * 60;
+	    if (days > 9)
+	        printf("   %3d %2d:%2.2d ", days, hours, minutes);
+	    else
+	        printf("   %d %2d:%2.2d:%2.2d", days, hours, minutes, total_time);
+	} else {
+	    printf("             ");
+	}
+}
+
+
+#else
 #if	SGI
 
-static summary(proc_family, rawreqp)
-pid_t	proc_family;		/* process family */
-struct  rawreq	*rawreqp;
+static summary(
+	pid_t	proc_family,		/* process family */
+	struct  rawreq	*rawreqp)
 {
 
 	struct	tm  *start_tm;
@@ -2392,6 +2467,7 @@ struct  rawreq	*rawreqp;
 
 	total_time = start_time = 0;
 	pid_oi = proc_family;
+
 #if	DEBUG_QSTAT
 	printf( "pid is %d\n", pid_oi);
 #endif
@@ -2425,7 +2501,7 @@ struct  rawreq	*rawreqp;
 	poffset =  proc_buff.p_child;
 	do_count = 0;
 	get_node(poffset, pid_oi, proc_family);
-
+  
 	if ( start_time ) {
 	    start_tm = localtime(&start_time);
 	    printf(" %2d/%2.2d %2.2d:%2.2d", start_tm->tm_mon+1,
@@ -2467,10 +2543,10 @@ struct  rawreq	*rawreqp;
 	    printf("             ");
 	}
 }
-static get_node(pointer, pid_oi, proc_family)
-struct proc *pointer;
-pid_t	pid_oi;
-pid_t	proc_family;
+static get_node(
+	struct proc *pointer,
+	pid_t	pid_oi,
+	pid_t	proc_family)
 {
 	int	status;
 	struct  user  *uptr;
@@ -2529,11 +2605,13 @@ pid_t	proc_family;
 	status = get_node(proc_buff.p_sibling, pid_oi, proc_family);
 }
 #endif
-#if	IBMRS
+#endif
 
-static summary(proc_family, rawreqp)
-pid_t	proc_family;			    /* process family */
-struct  rawreq	*rawreqp;
+
+#if	IBMRS
+static summary(
+	pid_t	proc_family,	    /* process family */
+	struct  rawreq	*rawreqp)
 {
 
 	struct	tm  *start_tm;
@@ -2604,10 +2682,10 @@ struct  rawreq	*rawreqp;
 	    printf("             ");
 	}
 }
-static get_node(pointer, pid_oi, proc_family)
-int	pointer;
-pid_t	pid_oi;
-pid_t	proc_family;
+static get_node(
+	int	pointer,
+	pid_t	pid_oi,
+	pid_t	proc_family)
 {
 	int	status;
 	struct  user  myuser;
@@ -2630,9 +2708,9 @@ pid_t	proc_family;
 	if (myproc.p_pid == pid_oi) do_count = 0;
 	status = get_node(myproc.p_siblings, pid_oi, proc_family);
 }
-static findproc(address,  myproc)
-unsigned long address;
-struct proc *myproc;
+static findproc(
+	unsigned long address,
+	struct proc *myproc)
 {
     int	    rtn;
     unsigned long   offset;
@@ -2643,9 +2721,8 @@ struct proc *myproc;
     if (rtn == -1) return (0);
     return(1);
 }
-finduser(pid,  user)
-long	pid;
-struct user *user;
+
+finduser(long pid,  struct user *user)
 {
     struct procinfo pinfo[MAX_PROC];
     int	proc_no,  nproc;
@@ -2669,9 +2746,9 @@ struct user *user;
 
 #if	HPUX
 
-static summary(proc_family, rawreqp)
-pid_t	proc_family;			    /* process family */
-struct  rawreq	*rawreqp;
+static summary(
+	pid_t	proc_family,	    /* process family */
+	struct  rawreq	*rawreqp)
 {
 
     struct	tm  *start_tm;
@@ -2775,9 +2852,9 @@ struct  rawreq	*rawreqp;
     }
 }
 
-get_process_info(pid, proc_family)
-pid_t pid;
-pid_t proc_family;
+get_process_info(
+	pid_t pid,
+	pid_t proc_family)
 {
     int i;
     struct proc *pp;
@@ -2793,6 +2870,7 @@ pid_t proc_family;
         if (pp->p_ppid == pid) get_process_info(pp->p_pid);
      }
 }
+
 /*
  *  getkval(offset, ptr, size, refstr) - get a value out of the kernel.
  *      "offset" is the byte offset into the kernel for the desired value,
@@ -2802,12 +2880,11 @@ pid_t proc_family;
  *
  */
 
-getkval(offset, ptr, size, refstr)
-
-unsigned long offset;
-int *ptr;
-int size;
-char *refstr;
+getkval(
+	unsigned long offset,
+	int *ptr,
+	int size,
+	char *refstr)
 
 {
     if (lseek(memfd, (long)offset, L_SET) == -1) {
@@ -2824,6 +2901,7 @@ char *refstr;
 }
 
 #endif
+
 static sho_mon_hdr()
 {
 printf(
