@@ -180,9 +180,7 @@ time_t last_report_time = 0;
  *      int main():
  *      Start of the NQS load daemon.
  */
-main(argc,argv)
-int argc;
-char *argv[];
+main(int argc, char *argv[])
 {
     static char logfile_buffer [BUFSIZ];    /* logfile output buffer */
 
@@ -510,8 +508,7 @@ static void load_daeshutdown()
 #if HAVE_MONITOR
 #if SGI
 static
-void calcloadavg(load)
-double load[3];
+void calcloadavg(double load[3])
 {
     unsigned long	kernaddr;
     static int kmem = -1;
@@ -559,17 +556,13 @@ double load[3];
 #define LOADAVGD_LOCATION "/usr/local/bin/loadavgd"
 #endif
 
-static int signal_handler(sig, code, scp)
-int sig;
-int code;
-struct sigcontext *scp;
+static int signal_handler(int sig, int code, struct sigcontext *scp)
 {
     /* set this signal-handler again */
     signal(sig,signal_handler);
 }
 
-static void calcloadavg(loadv)
-double loadv[];
+static void calcloadavg(double loadv[])
 {
     static int initted=0;
     static int sock;
@@ -682,8 +675,7 @@ struct  nlist nl[] = {
         { 0 },
 };
 static
-void calcloadavg(load)
-double load[3];
+void calcloadavg(double load[3])
 {
     static int kmem = -1;
     double avenrun[3];
@@ -728,8 +720,7 @@ struct  nlist nl[] = {
 };
 
 static
-void calcloadavg(load)
-double load[3];
+void calcloadavg(double load[3])
 {
     static int kmem = -1;
     long avenrun[3];
@@ -775,8 +766,7 @@ double load[3];
 #else
 #if 	IBMRS
 static
-void calcloadavg(load)
-double load[3];
+void calcloadavg(double load [3])
 {
   int iparam;
 
@@ -785,8 +775,7 @@ double load[3];
   }
 }
 
-static loadavg_init(observ)
-int observ[3];
+static loadavg_init(int observ[3])
 {
   int iobs, iparam;
   for (iparam=0;iparam<3;iparam++) {
@@ -801,8 +790,7 @@ int observ[3];
 }
 
 static
-update_loadavg(observ)
-int observ[3];
+update_loadavg(int observ[3])
 {
   static int prev_update=0;
 
@@ -816,8 +804,7 @@ int observ[3];
 #define RB_INC(index) ((index+1>=(SIZE_STORE))?(0):(index+1))
 
 static
-loadavg_put(observ)
-int observ[3];
+loadavg_put(int observ[3])
 {
   int iparam;
 
@@ -862,8 +849,7 @@ void handle_loadavg()
  * For now just return 9999 for the load average.
  */
 static
-void calcloadavg(load)
-double load[3];
+void calcloadavg(double load[3])
 {
 	load[0] = 9999.;
 	load[1] = 9999.;
