@@ -197,9 +197,7 @@ static FILE *logfile = NULL;		/* Logfile; Not null if log */
  *	int main ():
  *	NQS logdaemon.
  */
-int main (argc, argv)
-int argc;
-char *argv[];
+int main (int argc, char *argv[])
 {
 	static char badlog[] = "%s(ERROR): Bad log message follows.\n";
 
@@ -354,8 +352,7 @@ BAD SYSTEM TYPE
  *	This function will exit(), if there aren't any processes
  *	with the NQS log message packet pipe open for writing.
  */
-static void get_message (buffer)
-char buffer [BUFSIZ+1];			/* Line buffer */
+static void get_message (char buffer[BUFSIZ+1])
 {
 	static char badpk[] = "%s(WARN):  Bad NQS log msg follows.\n";
 	static char exiting[] = "%s(INFO):  NQS log process exiting.\n";
@@ -422,8 +419,7 @@ char buffer [BUFSIZ+1];			/* Line buffer */
  *	A success/fail code is returned directly to the NQS
  *	daemon.
  */
-static void setlogfile (newlogname)
-register char *newlogname;		/* Name of new logfile. */
+static void setlogfile (char *newlogname)
 {
 	static char
 	fail[] = "%s(ERROR): New logfile request failed.\n";
