@@ -1275,9 +1275,7 @@ static short chset[96][CHEIGHT] =
  *	where nnn specifies (in integer ASCII decimal), the debug
  *	level in effect when this process was forked from NQS.
  */
-main (argc, argv)
-int argc;
-char *argv [];
+main (int argc, char *argv[])
 {
 
 	register char *cp;		/* Pointer to character */
@@ -1935,8 +1933,7 @@ BAD SYSTEM TYPE
  *	void nqs():
  *	Display flag page header/footer to stdout.
  */
-static void nqs (width)
-int width;				/* Width of line printer */
+static void nqs (int width)
 {
 	static char text[] = "Network Queueing System*";
 
@@ -1965,9 +1962,7 @@ int width;				/* Width of line printer */
  *	Display the specified character string as a horizontal banner
  *	to stdout.
  */
-static void banner (string, width)
-char *string;				/* String to be printed */
-int width;				/* Width of line printer */
+static void banner (char *string, int width)
 {
 	register short i;		/* Counter */
 	register short column;		/* Column [0..n] */
@@ -2128,8 +2123,7 @@ static void doformfeed()
  *	void restore():
  *	Restore original device state, waiting for output to drain.
  */
-static void restore (sig)
-int sig;				/* Signal received */
+static void restore (int sig)
 {
 	if (queued_signal++) {
 		/*
