@@ -606,9 +606,7 @@ char *packet_types[] =
  *	int main():
  *	Start of the NQS local daemon.
  */
-int main (argc, argv)
-int argc;
-char *argv[];
+int main (int argc, char *argv[])
 {
 	int integers;			/* Number of 32-bit precision signed-*/
 					/* integer values present in the */
@@ -2339,11 +2337,11 @@ static int getpchar ()
  *	Write a message to the NQS log process concerning the bad packet
  *	received.
  */
-static void badpacket (pid, ruid, report_protocol_error)
-int pid;				/* Process id */
-uid_t ruid;				/* Real user-id */
-int report_protocol_error;		/* Boolean report protocol error */
-					/* in packet, if non-zero. */
+static void badpacket (
+	int pid,			/* Process id */
+	uid_t ruid,			/* Real user-id */
+	int report_protocol_error)	/* Boolean report protocol error */
+				/* in packet, if non-zero. */
 {
 	if (report_protocol_error) nqs_complt (TCML_PROTOFAIL, pid);
 	printf ("E$Bad packet received from process %1d.\n", pid);
@@ -2359,8 +2357,7 @@ int report_protocol_error;		/* Boolean report protocol error */
  *	int invalidunits():
  *	Return non-zero if the specified quota limit units are invalid.
  */
-static int invalidunits (units)
-short units;				/* Quota limit units */
+static int invalidunits (short units)
 {
 	switch (units) {
 	case QLM_BYTES:
@@ -2383,9 +2380,7 @@ short units;				/* Quota limit units */
  *	void showbytes():
  *	Show byte/string datum as received in message packet.
  */
-static void showbytes (bytes, length)
-register char *bytes;			/* Array of bytes. */
-register unsigned length;		/* Length of byte array. */
+static void showbytes (char *bytes, unsigned length)
 {
 	register short ch;		/* Byte/character */
 	register int col;		/* Column counter */
@@ -2440,9 +2435,7 @@ register unsigned length;		/* Length of byte array. */
  *		   than, or equal to size_limit.
  *		0: otherwise.
  */
-static int validstr (str_n, size_limit)
-register int str_n;			/* Message packet string [n] */
-register int size_limit;		/* Maximum size limit */
+static int validstr (int str_n, int size_limit)
 {
 	register int size;
 
