@@ -121,18 +121,18 @@ static void subs_seqno (/* char *cp, int seqno */);
  *		The information completion code portion of the return
  *		value is 0.
  */
-long nqs_quereq (mode, ctrlname, orig_seqno, orig_mid, destqueue, frommid)
-int mode;				/* Queueing mode:  0=new; 1=local */
+long nqs_quereq (
+	int mode,			/* Queueing mode:  0=new; 1=local */
 					/* pipe queue; 2=remote pipe queue */
-char *ctrlname;				/* The name of the req control file */
+	char *ctrlname,			/* The name of the req control file */
 					/* (Only meaningful if mode = 0) */
-long orig_seqno;			/* Original request sequence# */
+	long orig_seqno,		/* Original request sequence# */
 					/* (Only meaningful if mode > 0) */
-Mid_t orig_mid;				/* Original request machine-id */
+	Mid_t orig_mid,			/* Original request machine-id */
 					/* (Only meaningful if mode > 0) */
-char *destqueue;			/* Destination queue */
+	char *destqueue,		/* Destination queue */
 					/* (Only meaningful if mode > 0) */
-Mid_t frommid;				/* Machine delivering request */
+	Mid_t frommid)			/* Machine delivering request */
 {					/* (Only meaningful if mode = 2) */
 
 	char newpath [MAX_PATHNAME+1];	/* New pathname */
@@ -517,14 +517,13 @@ Mid_t frommid;				/* Machine delivering request */
  *		 0: Path resolved successfully.
  *		-1: Resolved path is too long.
  */
-static int resolvepath (rawreq, mid_resolve, path_resolve, access_mode, length,
-			suffixchar)
-register struct rawreq *rawreq;		/* Raw request structure for request */
-Mid_t *mid_resolve;			/* Machine-id requiring resolution */
-register char *path_resolve;		/* Path requiring resolution */
-short access_mode;			/* Access mode */
-register int length;			/* Len of path requiring resolution */
-char suffixchar;			/* Suffix char for default */
+static int resolvepath (
+	struct rawreq *rawreq,		/* Raw request structure for request */
+	Mid_t *mid_resolve,		/* Machine-id requiring resolution */
+	register char *path_resolve,	/* Path requiring resolution */
+	short access_mode,		/* Access mode */
+	register int length,		/* Len of path requiring resolution */
+	char suffixchar)		/* Suffix char for default */
 {
 	char dirpath [MAX_REQPATH+1];	/* Output file pathname */
 
@@ -567,10 +566,10 @@ char suffixchar;			/* Suffix char for default */
  *				the current mapped user-id of the
  *				request owner.
  */
-long nqs_holdreq (mapped_uid, orig_seqno, orig_mid)
-uid_t mapped_uid;			/* Mapped owner user-id */
-long orig_seqno;			/* Original request sequence# */
-Mid_t orig_mid;				/* Original machine-id of req */
+long nqs_holdreq (
+	uid_t mapped_uid,	/* Mapped owner user-id */
+	long orig_seqno,	/* Original request sequence# */
+	Mid_t orig_mid)		/* Original machine-id of req */
 {
 	struct request *predecessor;	/* Predecessor in req set in queue */
 	int state;			/* Request queue state: RQS_ */
@@ -661,10 +660,10 @@ Mid_t orig_mid;				/* Original machine-id of req */
  *				request owner.
  *		TCML_REQNOTHELD:if the specified request is not held.
  */
-long nqs_relreq (mapped_uid, orig_seqno, orig_mid)
-uid_t mapped_uid;			/* Mapped owner user-id */
-long orig_seqno;			/* Original request sequence# */
-Mid_t orig_mid;				/* Original machine-id of req */
+long nqs_relreq (
+	uid_t mapped_uid,	/* Mapped owner user-id */
+	long orig_seqno,	/* Original request sequence# */
+	Mid_t orig_mid)		/* Original machine-id of req */
 {
 	struct request *predecessor;	/* Predecessor in req set in queue */
 	int state;			/* Request queue state: RQS_ */
@@ -752,10 +751,10 @@ Mid_t orig_mid;				/* Original machine-id of req */
  *		 0:	if successful.
  *		-1:	if failure.
  */
-static int flag_upd (req, setflags, clflags)
-struct request *req;			/* Ptr to request structure */
-short setflags;				/* Flags to set */
-short clflags;				/* Flags to clear */
+static int flag_upd (
+	struct request *req,		/* Ptr to request structure */
+	short setflags,			/* Flags to set */
+	short clflags)			/* Flags to clear */
 {
 	int cfd;			/* File descriptor for control file */
 	struct rawreq rawreq;		/* Raw request structure */
@@ -791,9 +790,7 @@ short clflags;				/* Flags to clear */
  * the ascii sequence number.
  */
 static
-void subs_seqno (name, seqno)
-char *name;			/* Pointer to name containing 1 or more tokens */
-int seqno;			/* Number to substitute (in ascii) for token */
+void subs_seqno (char *name, int seqno)
 {
     char *cp, *acp, *dcp;		/* Utility character pointers */
     char dirpath [MAX_REQPATH+1];	/* Output file pathname */
