@@ -280,15 +280,15 @@ struct pipe_dest {
  *
  *
  */
-void nqs_reqser (request, rawreq, restartflag, queue, device, passwd)
-struct request *request;		/* Request structure */
-struct rawreq *rawreq;			/* Raw request header from */
-					/* control file */
-int restartflag;			/* BOOLEAN request is restarting */
+void nqs_reqser (
+	struct request *request,	/* Request structure */
+	struct rawreq *rawreq,		/* Raw request header from */
+						/* control file */
+	int restartflag,		/* BOOLEAN request is restarting */
 					/* execution */
-struct nqsqueue *queue;			/* Queue being served */
-struct device *device;			/* Device to use (can be NIL) */
-struct passwd *passwd;			/* Password entry for request */
+	struct nqsqueue *queue,		/* Queue being served */
+	struct device *device,		/* Device to use (can be NIL) */
+	struct passwd *passwd)		/* Password entry for request */
 {
 
 #if	MAX_QUEUENAME > MAX_DEVNAME
@@ -1403,6 +1403,43 @@ BAD SYSTEM TYPE
 		
         }
 
+#if     TAMU
+        if (queue->q.type == QUE_BATCH) {
+                char psetcmd[128];
+                char tmpdir[MAX_PATHNAME];
+                char mkcmd[MAX_PATHNAME + 25];
+
+        	/* TAMU MOD to set processor set */
+                sprintf(psetcmd,"/sbin/pset -p %d %s >/dev/null",
+                        getpid(),rawreq->quename);
+                system(psetcmd);
+
+        	/* TAMU MOD to add work directory with cleanup */
+                /* build work directory  /work/queue/tmpname */
+                sprintf(tmpdir, "/work/%s/%d.%s", rawreq->quename,
+                        rawreq->orig_seqno, hostname);
+                sprintf(mkcmd,"/sbin/mkdir -p -m 755 %s",tmpdir);
+                system(mkcmd);
+                chown(tmpdir,passwd->pw_uid,passwd->pw_gid);
+
+                /* set TMPDIR */
+                cp = environment + envpsize;
+                envp [envpcount++] = cp;
+                envpsize += sprintf (cp, "TMPDIR=%s", tmpdir) + 1;
+                envp [envpcount] = (char *) 0;
+
+                /*
+                 *  Display start information.  Note that we have to use
+                 *  stderr, since stdout is used for devices....
+                 */
+                fprintf (stderr, "D$nqs_reqser(): start %d.%s in %s\n",
+                        rawreq->orig_seqno,
+                        rawreq->quename,
+                        hostname);
+                fflush (stderr);
+        }
+#endif
+
 	if (queue->q.type == QUE_BATCH || queue->q.type == QUE_DEVICE) {
 		/* 
 		 * For SGI set priority down low out of way of interactives
@@ -1776,15 +1813,15 @@ BAD SYSTEM TYPE
  *		   for the stderr file;
  *	       -1: if an error occurs in which case errno is set.
  */
-static int mkspool (rawreq, namefn, passwd, filemask)
-struct rawreq *rawreq;			/* Rawreq structure for request */
-char *(*namefn)();			/* Ptr to fn returning ptr to char */
-struct passwd *passwd;			/* Password file entry for owner */
-int filemask;				/* File create/truncate flag */
+static int mkspool (
+	struct rawreq *rawreq,		/* Rawreq structure for request */
+	char *(*namefn)(),		/* Ptr to fn returning ptr to char */
+	struct passwd *passwd,		/* Password file entry for owner */
+	int filemask)			/* File create/truncate flag */
 {
-	register int fd;		/* File descriptor */
-	register char *path;		/* Ptr to temp file path */
-	register int cmask;		/* umask */
+	int fd;		/* File descriptor */
+	char *path;		/* Ptr to temp file path */
+	int cmask;		/* umask */
 
 	/*
 	 *  Generate name of temporary spooled output file.
@@ -1878,8 +1915,7 @@ static void serexecute ()
  * with "PATH=" and if found, uses the rest of the line as the path (without
  * checking it!).  Otherwise,  it uses guess for the proper path.
  */
-static char *get_the_path(passwd)
-struct passwd    *passwd;
+static char *get_the_path(struct passwd *passwd)
 {
     static char    the_path[MAX_PATHNAME+1];
     FILE    *environment_file;
