@@ -41,6 +41,7 @@
 *	V01.6	JRR	24-Feb-1994	Fixed bzero (again!).
 *	V01.7	JRR	01-Mar-1994	Added support for SOLARIS.
 *	V01.8	JRR	05-Aug-1994	Further fixes.
+*	V01.9	JRR	09-Nov-1994	Fix memcpy.
 */
 /*++ qacct.c - Network Queueing System
  *
@@ -138,6 +139,7 @@ int write_summary;		/* Flag: true if writing summary, False o/w */
 int summary_fd;			/* Summary file descriptor */
 int do_rollover;		/* Flag: true if doing rollover, False o/w */
 int summary_report;		/* Flag: true if doing summary report, False o/w */
+int submission_time;		/* Flag: true if print submission time, False o/w */
 struct userqstruct userqhead;	/* Header for userqheader */
 
 /*** main
@@ -150,15 +152,14 @@ struct userqstruct userqhead;	/* Header for userqheader */
  *	    -b time     prints records completed before that time
  *	    -f		prints everything
  *	    -i filename uses that file as input (default is NQSACCT_FILE)	
+ *	    -m		prints submission time in report
  *	    -o filename Output filename for binary summary files.
  *	    -r		Rollover nqs accounting file
  *	    -s		Create summary output file	
  *	    -u username prints records for that username
  *	    -v		prints version
  */
-main (argc, argv)
-int argc;
-char *argv[];                           
+main (int argc, char *argv[])
 {
     register int i;
     int fd_acct;			/* Accounting file descriptor */
@@ -248,6 +249,9 @@ char *argv[];
                     }
                     sourcefilename = *argv;
                     break;
+                case 'm':		/* Want submission time. */
+                    submission_time++;
+                    break;
                 case 'o':               /* Output file name specification */
                     if (*++argv == NULL) {
                         fprintf (stderr, "Missing output filename.\n");
@@ -267,7 +271,7 @@ char *argv[];
                     break;
                 case 'S':		/* Produce summary report */
                     summary_report++;
-		    memset (&userqhead,  NULL, sizeof (struct userqstruct) );
+		    memset (&userqhead, (int) NULL, sizeof (struct userqstruct) );
                     break;
                 case 'u':               /* User-name specification */
                     if (*++argv == NULL) {
@@ -316,7 +320,7 @@ char *argv[];
 	fprintf(stderr, "-s and -S are incompatable qacct switches\n");
 	exit (1);	
     }
-    memset ( &acct_list_head,  NULL, sizeof(acct_list_head) );
+    memset ( &acct_list_head, (int) NULL, sizeof(acct_list_head) );
     if (sourcefilename != NULL)
 	    fd_acct = open(sourcefilename, O_RDONLY, 0644);
     else
@@ -546,7 +550,7 @@ BAD SYSTEM TYPE
 		exit(1);
 	    }
 	    arp = malloc(sizeof(acct_list_head) );
-	    memset ( arp,  NULL, sizeof(acct_list_head) );
+	    memset ( arp, (int) NULL, sizeof(acct_list_head) );
 	    strcpy(arp->user,  acct_init1.user);
 	    if (full) {
 	         printf(" INIT_1 request %s (%d.%s) ", acct_init1.reqname, 
@@ -582,7 +586,7 @@ BAD SYSTEM TYPE
 		exit(1);
 	    }
 	    arp = malloc(sizeof(acct_list_head) );
-	    memset ( arp, NULL, sizeof(acct_list_head) );
+	    memset ( arp, (int) NULL, sizeof(acct_list_head) );
 	    strcpy(arp->user,  acct_init.user);
 	    if (full) {
 	         printf(" INIT request %d.%s ",acct_init.seqno,  
@@ -758,9 +762,9 @@ BAD SYSTEM TYPE
  *
  * Print out any records that have an init,  but no stat or term.
  */
-static print_outstanding_req(arp, type)
-struct acct_record *arp;
-char *type;
+static print_outstanding_req(
+	struct acct_record *arp,
+	char *type)
 {
     struct acct_record *sa_arp, *arp_ptr;
     int  header_printed = 0;
@@ -788,8 +792,7 @@ char *type;
  *      void bad_syntax():
  *      Display message and exit.
  */
-static void bad_syntax (flag)
-char *flag;                             /* Which flag */
+static void bad_syntax (char *flag)
 {
         fprintf (stderr, "Invalid syntax following -%s flag.\n", flag);
         exit(0);                    /* Exit */
@@ -802,8 +805,7 @@ char *flag;                             /* Which flag */
  *      void bad_value ():
  *      Display message and exit.
  */
-static void bad_value (flag)
-char *flag;                             /* Which flag */
+static void bad_value (char *flag)
 {
         fprintf (stderr, "Invalid value following -%s flag.\n", flag);
         exit(0);                    /* Exit */
@@ -815,8 +817,7 @@ char *flag;                             /* Which flag */
  * no termination record (yet have seen a status).  Since it is a
  * startup or shutdown situation we will not see a real termination.
  */
-static print_partial_req(arp)
-struct acct_record *arp;
+static print_partial_req(struct acct_record *arp)
 {
     struct acct_record *sa_arp, *arp_ptr, *arp_prev;
     unsigned long cpu_time;
@@ -848,8 +849,7 @@ struct acct_record *arp;
  * Print the termination record here.
  */
 static
-void print_termination (arp)
-struct acct_record *arp;
+void print_termination (struct acct_record *arp)
 {
     struct tm *tp;
     double cpu_time;
@@ -880,6 +880,11 @@ BAD SYSTEM TYPE
         printf(" %d-%2.2d-%2.2d:%2.2d:%2.2d:%2.2d", tp->tm_year,  
 	    tp->tm_mon+1,  tp->tm_mday, tp->tm_hour,  tp->tm_min,  tp->tm_sec);
     }
+    if (submission_time) { 
+        tp = localtime(&arp->sub_time);
+        printf(" %d-%2.2d-%2.2d:%2.2d:%2.2d:%2.2d", tp->tm_year,  
+	    tp->tm_mon+1,  tp->tm_mday, tp->tm_hour,  tp->tm_min,  tp->tm_sec);
+    }
     printf(" %s", arp->reqname);    
     printf("\n");
 }
@@ -889,8 +894,7 @@ BAD SYSTEM TYPE
  * Print the summary record here.
  */
 static
-void print_summary (arp)
-struct nqsacct_summ *arp;
+void print_summary (struct nqsacct_summ *arp)
 {
     struct tm *tp;
     double cpu_time;
@@ -902,8 +906,9 @@ struct nqsacct_summ *arp;
 #if	IBMRS
     cpu_time = (double) (arp->s_time+arp->u_time);
     printf(" %9.2f",  cpu_time/100.0);
-#endif
+#else
     printf(" %9d", arp->s_time+arp->u_time);
+#endif
     tp = localtime(&arp->init_time);
     printf(" %d-%2.2d-%2.2d:%2.2d:%2.2d:%2.2d", tp->tm_year,  
 	tp->tm_mon+1,  tp->tm_mday, tp->tm_hour,  tp->tm_min,  tp->tm_sec);
@@ -912,6 +917,11 @@ struct nqsacct_summ *arp;
         printf(" %d-%2.2d-%2.2d:%2.2d:%2.2d:%2.2d", tp->tm_year,  
 	    tp->tm_mon+1,  tp->tm_mday, tp->tm_hour,  tp->tm_min,  tp->tm_sec);
     }
+    if (submission_time) { 
+        tp = localtime(&arp->sub_time);
+        printf(" %d-%2.2d-%2.2d:%2.2d:%2.2d:%2.2d", tp->tm_year,  
+	    tp->tm_mon+1,  tp->tm_mday, tp->tm_hour,  tp->tm_min,  tp->tm_sec);
+    }
     printf(" %s", arp->reqname);    
     printf("\n");
 }
@@ -920,12 +930,11 @@ struct nqsacct_summ *arp;
  * Write out the summary records to the file here
  */
 static
-void do_write_summary( arp)
-struct acct_record  *arp;
+void do_write_summary(struct acct_record * arp)
 {
     struct nqsacct_summ  acct_summ;
     
-    memset ( &acct_summ, NULL, sizeof(acct_summ) );
+    memset ( &acct_summ, (int) NULL, sizeof(acct_summ) );
     acct_summ.h.type = NQSACCT_SUMM;
     acct_summ.h.length = sizeof(acct_summ);
     strcpy(acct_summ.user, arp->user);
@@ -958,10 +967,10 @@ BAD SYSTEM TYPE
  * Do the rollover processing.
  */
 static
-void process_rollover(arp, acct_startup, fd_acct)
-struct acct_record *arp;
-struct nqsacct_startup *acct_startup;
-int fd_acct;
+void process_rollover(
+	struct acct_record *arp,
+	struct nqsacct_startup *acct_startup,
+	int fd_acct)
 {
 
     struct acct_record *sa_arp, *arp_ptr;
@@ -980,10 +989,10 @@ int fd_acct;
 	exit (1);
     }  
     /*
-     * open tmp file as /usr/tmp/nqs-acct.PID
+     * open tmp file as /usr/adm/nqs-acct.PID
      */
     mypid = getpid( );
-    sprintf (tmp_filename, "/usr/tmp/qacct.%x", mypid);
+    sprintf (tmp_filename, "/usr/adm/qacct.%x", mypid);
     fd_tmp = open(tmp_filename, O_WRONLY|O_CREAT|O_APPEND, 0644);
     if (fd_tmp < 0) {
         perror ("Error opening temporary file");
@@ -1057,8 +1066,7 @@ int fd_acct;
  * Add the information to the user/usage summary.
  */
 static
-void add_sum_to_summary (arp)
-struct nqsacct_summ *arp;
+void add_sum_to_summary (struct nqsacct_summ *arp)
 {
     double record_cputime;
     struct userqstruct *userq_p, *userq_p2;
@@ -1083,7 +1091,7 @@ struct nqsacct_summ *arp;
 	fprintf(stderr,  "Error getting space for userqstruct structure.\n");
 	exit(1);
     }
-    memset (userq_p2, NULL, sizeof (struct userqstruct) );
+    memset (userq_p2, (int) NULL, sizeof (struct userqstruct) );
     userq_p->next = userq_p2;
     strcpy (userq_p2->user, arp->user);
     strcpy (userq_p2->queue, arp->queue);
@@ -1093,15 +1101,14 @@ struct nqsacct_summ *arp;
 #if	IBMRS
     record_cputime /= 100.0;
 #endif
-    userq_p->cputime = record_cputime;
+    userq_p2->cputime = record_cputime;
 
 }
 /*
  * Add the termination information to the user/queue summary.
  */
 static
-void add_term_to_summary( arp)
-struct acct_record  *arp;
+void add_term_to_summary(struct acct_record  *arp)
 {
     double record_cputime;
     struct userqstruct *userq_p, *userq_p2;
@@ -1113,10 +1120,10 @@ struct acct_record  *arp;
 			!strcmp(userq_p->user, arp->user) ){
 	    userq_p->count += 1;
 #if     HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
-	    record_cputime = arp->tms_utime + arp->tms_stime;
+	    record_cputime = (double) arp->tms_utime + arp->tms_stime;
 #else
 #if     BSD43 | ULTRIX | DECOSF
-	    record_cputime = arp->u_sec + arp->s_sec;
+	    record_cputime = (double) arp->u_sec + arp->s_sec;
 #else
 BAD SYSTEM TYPE
 #endif
@@ -1135,17 +1142,17 @@ BAD SYSTEM TYPE
 	fprintf(stderr,  "Error getting space for userqstruct structure.\n");
 	exit(1);
     }
-    memset (userq_p2, NULL, sizeof (struct userqstruct) );
+    memset (userq_p2, (int) NULL, sizeof (struct userqstruct) );
     userq_p->next = userq_p2;
     strcpy (userq_p2->user, arp->user);
     strcpy (userq_p2->queue, arp->queue);
-    userq_p2->count += 1;
+    userq_p2->count = 1;
 	
 #if     HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
-    record_cputime = arp->tms_utime + arp->tms_stime;
+    record_cputime = (double) arp->tms_utime + arp->tms_stime;
 #else
 #if     BSD43 | ULTRIX | DECOSF
-    record_cputime = arp->u_sec + arp->s_sec;
+    record_cputime = (double) arp->u_sec + arp->s_sec;
 #else
 BAD SYSTEM TYPE
 #endif
@@ -1153,7 +1160,7 @@ BAD SYSTEM TYPE
 #if	IBMRS
     record_cputime /= 100.0;
 #endif
-    userq_p->cputime = record_cputime;
+    userq_p2->cputime = record_cputime;
 }
 
 /*
@@ -1178,7 +1185,7 @@ void produce_summary_report()
     double total_cputime = 0.0;
     char *count_format = "%6d %9.0f   ";
     
-    memset (&qhead, NULL, sizeof (struct qstruct) );
+    memset (&qhead, (int) NULL, sizeof (struct qstruct) );
     userq_p = userqhead.next;
     
     printf("NQS queue usage summary -- number of jobs and cumulative Cpu seconds\n");
@@ -1201,7 +1208,7 @@ void produce_summary_report()
 		    exit (1);
 		}
 		q_count++;
-		memset (q_p2, NULL, sizeof(struct qstruct) );
+		memset (q_p2, (int) NULL, sizeof(struct qstruct) );
 		q_p->next = q_p2;
 		strcpy (q_p2->queue, userq_p->queue);
 		q_p2->count = userq_p->count;
@@ -1218,7 +1225,7 @@ void produce_summary_report()
 	fprintf(stderr,  "Error getting space for q_array.\n");
 	exit (1);
     }
-    memset (q_array, NULL, q_count * sizeof (struct qstruct));
+    memset (q_array, (int) NULL, q_count * sizeof (struct qstruct));
     q_p2 = q_array;
     q_p = qhead.next;
     while (q_p != (struct qstruct *) NULL ) {
@@ -1232,7 +1239,7 @@ void produce_summary_report()
 	fprintf(stderr,  "Error getting space for userq_array.\n");
 	exit (1);
     }
-    memset (userq_array, NULL, userq_count * sizeof (struct userqstruct));
+    memset (userq_array, (int) NULL, userq_count * sizeof (struct userqstruct));
     userq_p2 = userq_array;
     userq_p = userqhead.next;
     while (userq_p != (struct userqstruct *) NULL ) {
@@ -1300,14 +1307,12 @@ void produce_summary_report()
 }
 
 static
-int q_sortrtn(a, b)
-struct qstruct *a, *b;
+int q_sortrtn(struct qstruct *a, struct qstruct *b)
 {
     return (strcmp (a->queue, b->queue) );
 }
 static
-int userq_sortrtn(a, b)
-struct userqstruct *a, *b;
+int userq_sortrtn(struct userqstruct *a, struct userqstruct *b)
 {
     if ( !strcmp(a->user, b->user)) return (strcmp (a->queue, b->queue) );
     else return (strcmp (a->user, b->user) );
@@ -1335,6 +1340,7 @@ fprintf (stderr, " -b since-time   selects records finishing before time\n");
 fprintf (stderr, " -f              full dump of all records\n");
 fprintf (stderr, " -i inputfile    indicates location of input file\n");
 fprintf (stderr, "                        default is /usr/adm/nqs\n");
+fprintf (stderr, " -m              prints submission time in report\n");
 fprintf (stderr, " -o outputfile   indicates where summary file is to be written\n");
 fprintf (stderr, " -r              accounting file is rolled over\n");
 fprintf (stderr, " -s              creates a summary file\n");
